# zabel-commons

## Overview

This is part of the Zabel platform.  The **zabel.commons** package contains
interfaces, exceptions, and helpers that are used throughout the platform.

It is not typically installed as a standalone package but comes in as a
dependency from other packages.

If you want to develop a package that offer new _elements_ for Zabel, or if
you want to create an application that will be deployed using **zabel-fabric**,
you will probably have to add this package as a dependency for your package.

It provides five modules:

- _zabel.commons.exceptions_
- _zabel.commons.interfaces_
- _zabel.commons.sessions_
- _zabel.commons.servers_
- _zabel.commons.utils_

This package makes use of the **requests** library.  It has no other external
dependencies.

## License

```text
Copyright (c) 2019-2020 Martin Lafaix (martin.lafaix@external.engie.com) and others

This program and the accompanying materials are made
available under the terms of the Eclipse Public License 2.0
which is available at https://www.eclipse.org/legal/epl-2.0/

SPDX-License-Identifier: EPL-2.0
```
